@@ -62,7 +62,7 @@ for my $example (@examples) {
     my $output = $example;
     $output =~ s/\.pl$/-out.txt/;
     if (older ($output, $example) || $force) {
-	do_system ("perl -I$base/blib/lib -I$base/blib/arch $example > $output", $verbose);
+	do_system ("perl -I$base/blib/lib -I$base/blib/arch $example > $output 2>&1", $verbose);
     }
 }
 
